@@ -18,9 +18,9 @@ rpm --checksig kernel-2.6.27-76vl5.src.rpm || die "Can't verify signature."
 rpm -ivh kernel-2.6.27-76vl5.src.rpm || die "Can't install source package."
 
 cd /usr/src/vine/SOURCES/ || die "Can't chdir to /usr/src/vine/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20130214.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20130310.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20130214.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20130214.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20130310.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20130310.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -61,8 +61,8 @@ patch << "EOF" || die "Can't patch spec file."
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.3-20130214.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.27-vine-linux-5.2.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20130310.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.27-vine-linux-5.diff
 +
  cp %{SOURCE10} Documentation/
  
